@@ -1,7 +1,7 @@
 # Prints code testing coverage as percentage for badge generation.
-import xml.etree.ElementTree as et
+from defusedxml.ElementTree import parse
 
-tree = et.parse("cov.xml")
+tree = parse("cov.xml")
 root = tree.getroot()
 coverage = float(root.attrib["line-rate"]) * 100
 print(f"COVERAGE={coverage:3.4}%")
@@ -12,4 +12,4 @@ elif coverage >= 90.0:
 elif coverage >= 85.0:
     print("COVERAGE_COLOR=orange")
 else:
-    print("COVERAGE_COLOR=red")
\ No newline at end of file
+    print("COVERAGE_COLOR=red")
